#line 1 "libs/vkd3d-shader/hlsl.yy.c"

#line 3 "libs/vkd3d-shader/hlsl.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define hlsl_yy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer hlsl_yy_create_buffer
#endif

#ifdef yy_delete_buffer
#define hlsl_yy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer hlsl_yy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define hlsl_yy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer hlsl_yy_scan_buffer
#endif

#ifdef yy_scan_string
#define hlsl_yy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string hlsl_yy_scan_string
#endif

#ifdef yy_scan_bytes
#define hlsl_yy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes hlsl_yy_scan_bytes
#endif

#ifdef yy_init_buffer
#define hlsl_yy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer hlsl_yy_init_buffer
#endif

#ifdef yy_flush_buffer
#define hlsl_yy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer hlsl_yy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define hlsl_yy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state hlsl_yy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define hlsl_yy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer hlsl_yy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define hlsl_yypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state hlsl_yypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define hlsl_yypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state hlsl_yypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define hlsl_yyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack hlsl_yyensure_buffer_stack
#endif

#ifdef yylex
#define hlsl_yylex_ALREADY_DEFINED
#else
#define yylex hlsl_yylex
#endif

#ifdef yyrestart
#define hlsl_yyrestart_ALREADY_DEFINED
#else
#define yyrestart hlsl_yyrestart
#endif

#ifdef yylex_init
#define hlsl_yylex_init_ALREADY_DEFINED
#else
#define yylex_init hlsl_yylex_init
#endif

#ifdef yylex_init_extra
#define hlsl_yylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra hlsl_yylex_init_extra
#endif

#ifdef yylex_destroy
#define hlsl_yylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy hlsl_yylex_destroy
#endif

#ifdef yyget_debug
#define hlsl_yyget_debug_ALREADY_DEFINED
#else
#define yyget_debug hlsl_yyget_debug
#endif

#ifdef yyset_debug
#define hlsl_yyset_debug_ALREADY_DEFINED
#else
#define yyset_debug hlsl_yyset_debug
#endif

#ifdef yyget_extra
#define hlsl_yyget_extra_ALREADY_DEFINED
#else
#define yyget_extra hlsl_yyget_extra
#endif

#ifdef yyset_extra
#define hlsl_yyset_extra_ALREADY_DEFINED
#else
#define yyset_extra hlsl_yyset_extra
#endif

#ifdef yyget_in
#define hlsl_yyget_in_ALREADY_DEFINED
#else
#define yyget_in hlsl_yyget_in
#endif

#ifdef yyset_in
#define hlsl_yyset_in_ALREADY_DEFINED
#else
#define yyset_in hlsl_yyset_in
#endif

#ifdef yyget_out
#define hlsl_yyget_out_ALREADY_DEFINED
#else
#define yyget_out hlsl_yyget_out
#endif

#ifdef yyset_out
#define hlsl_yyset_out_ALREADY_DEFINED
#else
#define yyset_out hlsl_yyset_out
#endif

#ifdef yyget_leng
#define hlsl_yyget_leng_ALREADY_DEFINED
#else
#define yyget_leng hlsl_yyget_leng
#endif

#ifdef yyget_text
#define hlsl_yyget_text_ALREADY_DEFINED
#else
#define yyget_text hlsl_yyget_text
#endif

#ifdef yyget_lineno
#define hlsl_yyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno hlsl_yyget_lineno
#endif

#ifdef yyset_lineno
#define hlsl_yyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno hlsl_yyset_lineno
#endif

#ifdef yyget_column
#define hlsl_yyget_column_ALREADY_DEFINED
#else
#define yyget_column hlsl_yyget_column
#endif

#ifdef yyset_column
#define hlsl_yyset_column_ALREADY_DEFINED
#else
#define yyset_column hlsl_yyset_column
#endif

#ifdef yywrap
#define hlsl_yywrap_ALREADY_DEFINED
#else
#define yywrap hlsl_yywrap
#endif

#ifdef yyget_lval
#define hlsl_yyget_lval_ALREADY_DEFINED
#else
#define yyget_lval hlsl_yyget_lval
#endif

#ifdef yyset_lval
#define hlsl_yyset_lval_ALREADY_DEFINED
#else
#define yyset_lval hlsl_yyset_lval
#endif

#ifdef yyget_lloc
#define hlsl_yyget_lloc_ALREADY_DEFINED
#else
#define yyget_lloc hlsl_yyget_lloc
#endif

#ifdef yyset_lloc
#define hlsl_yyset_lloc_ALREADY_DEFINED
#else
#define yyset_lloc hlsl_yyset_lloc
#endif

#ifdef yyalloc
#define hlsl_yyalloc_ALREADY_DEFINED
#else
#define yyalloc hlsl_yyalloc
#endif

#ifdef yyrealloc
#define hlsl_yyrealloc_ALREADY_DEFINED
#else
#define yyrealloc hlsl_yyrealloc
#endif

#ifdef yyfree
#define hlsl_yyfree_ALREADY_DEFINED
#else
#define yyfree hlsl_yyfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define hlsl_yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 174
#define YY_END_OF_BUFFER 175
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[1065] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      175,  173,  156,  157,  173,  173,  173,  173,  173,  173,
      173,  173,  173,  173,  152,  152,  173,  173,  173,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  173,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  173,  158,  172,  171,  172,  164,
      172,  167,  166,  168,  167,  167,  163,  162,  163,  163,
      170,  169,  170,  156,  157,  136,    0,  146,    0,  141,
      127,  142,  139,  125,  137,  126,  138,  147,  140,  148,

      151,  152,    0,  152,  155,    0,  130,  134,  129,  135,
      132,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  144,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,   23,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,   33,   34,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  143,  128,  171,  164,    0,  166,  168,    0,

      165,    0,  162,    0,  169,    0,  147,    0,  148,  151,
      154,    0,  149,  155,  150,  131,  133,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,   28,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,    2,  145,  145,  145,   47,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,

      145,  145,  145,  145,  145,  145,  145,    3,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,    0,
        0,    0,  147,    0,  148,  154,  149,  150,  153,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,   46,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,    1,  145,    9,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,   24,  145,  145,  145,  145,  145,  145,  145,  145,
      145,   39,  145,  145,  145,  145,  145,  145,  145,   50,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,

      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  114,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  122,  145,  145,    0,    0,
      153,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,    6,  145,
      145,  145,  145,   16,  145,  145,  145,  145,  145,  145,
      145,  145,   27,  145,  145,  145,  145,   36,  145,  145,
      145,  145,  145,  145,  145,  145,  145,   54,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,   84,

      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,    4,  118,  145,  145,  145,  145,  145,
      124,    0,    0,  145,    7,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,   89,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
       25,   26,  145,  145,   35,  145,   41,   42,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,   65,
      145,  145,   83,  145,   87,   88,   90,   92,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  119,  145,  145,

      145,    0,    0,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,   10,  145,
      145,   14,  145,  145,   20,   21,  145,  145,   29,  145,
       40,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,   75,  145,  145,   93,  145,  145,   97,  145,  115,
      145,  117,  145,  145,  145,  159,    0,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
       67,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,   11,  145,  145,   17,

      145,  145,  145,  145,  145,  145,  145,  145,   63,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  112,  116,  145,  123,    0,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,   94,
       98,  101,  106,  145,  145,  145,  145,  145,  145,  145,
       43,  145,  145,  145,  145,  145,   66,   76,   77,   78,
      145,  145,  145,  145,   94,   99,  102,  107,  145,  145,
      145,    0,    5,  145,  145,  145,  145,  145,  145,   32,
       37,   38,  145,  145,  145,  145,  145,  145,  145,  145,

      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,   49,  145,  145,  145,
      145,   85,  145,  145,  145,  145,  145,    0,  145,  145,
      145,  145,  145,  145,   48,   51,   52,  145,  145,   70,
       72,   74,  145,  145,  145,  145,  145,  145,  145,  145,
      104,  108,  145,  145,  145,  145,   31,  145,  145,   53,
      145,   80,  145,  145,   95,   96,  109,  113,  145,    0,
      145,  145,  145,  145,   22,  145,  145,  145,  145,  145,
      145,  145,  145,  145,   81,  145,  145,  145,  145,  145,
      145,  120,   12,  145,  145,  145,  145,  145,  121,    0,

        0,  145,   15,   13,  145,  145,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
      145,  145,   45,  145,   82,  145,    0,    0,    0,  145,
      145,  145,   30,  145,  145,  145,  145,  145,  145,  145,
      145,  145,  100,  103,  145,  145,  111,  145,  145,  145,
        0,    0,  145,  145,  145,  145,  145,  145,  145,  145,
       62,  145,  145,  145,  145,  145,   44,  145,  145,    0,
        0,  145,  145,   19,  145,  145,   71,   73,  145,   64,
      145,   91,  105,  110,   86,    0,    0,    8,   18,  145,
      145,  145,  145,    0,    0,  145,   69,  145,  145,  145,

      145,    0,    0,   68,  145,  145,  145,  145,    0,    0,
      145,  145,  145,  145,    0,    0,  145,  145,  145,  145,
        0,    0,  145,  145,  145,   79,    0,    0,  160,   55,
      145,  145,    0,  145,  145,    0,  145,  145,  145,  145,
        0,  161,  145,   57,   59,   61,  145,  145,  145,  145,
      145,  145,  145,  145,  145,  145,  145,  145,  145,   58,
       60,  145,   56,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    1,    8,    9,    1,   10,
       11,   12,   13,    1,   14,   15,   16,   17,   18,   19,
       20,   21,   21,   21,   21,   22,   22,    1,    1,   23,
       24,   25,    1,    1,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   35,   35,   36,   37,   38,   39,   40,
       41,   42,   43,   44,   45,   46,   47,   35,   35,   35,
        1,   48,    1,   49,   50,    1,   51,   52,   53,   54,

       55,   56,   57,   58,   59,   60,   61,   62,   63,   64,
       65,   66,   67,   68,   69,   70,   71,   72,   73,   74,
       75,   76,    1,   77,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[78] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    2,    2,    2,    2,
        2,    2,    1,    1,    1,    2,    2,    2,    2,    2,
        2,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    1,    1,    3,
        2,    2,    2,    2,    2,    2,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    1
    } ;

static const flex_int16_t yy_base[1073] =
    {   0,
        0, 1300,   75,   81,   84,  102,   77,   79,  106,  108,
     1306, 1308, 1303, 1308, 1301, 1279,   83, 1278,   98, 1277,
      100,  101,   99, 1276,  133,  109,  109, 1275,  110,    0,
       87, 1233,   81, 1242, 1225, 1231, 1235, 1248, 1221,   79,
      109,   72,  129, 1236, 1266, 1218, 1220,  115,  106,  112,
      117,   72,  123,  131,  121,  138,  128,  147,  145,  150,
      172,  147,  166, 1229,  151, 1308, 1308, 1308, 1283,  215,
     1217, 1308, 1282, 1308, 1280,  207, 1308, 1308, 1279, 1230,
     1308, 1308, 1277, 1277, 1308, 1308,  211, 1308, 1275, 1308,
     1308, 1308, 1308, 1308, 1308, 1308, 1308,  243, 1308,  304,

      206,    0,  265,  174,  186,    0, 1253, 1308, 1308, 1308,
     1252,    0, 1220, 1218, 1203, 1209, 1205, 1207, 1204, 1206,
     1201, 1202, 1229, 1194, 1189, 1203,  214, 1192, 1196, 1196,
     1190,   86,  201, 1198, 1188, 1308, 1185, 1199,  169, 1182,
     1188, 1200, 1199,  207,  187, 1180,    0, 1184, 1178, 1175,
      180, 1183, 1176, 1184, 1185, 1171, 1175,    0,  191, 1175,
     1174, 1167, 1166, 1172, 1161,  222, 1178, 1162,  236, 1157,
     1171,  207, 1177,  233, 1155, 1164,  242,  234, 1161,  243,
     1166, 1153,  276,  238,  237, 1157,  250, 1163,  199, 1153,
      254, 1161, 1308, 1308, 1308,  323, 1168, 1216, 1308,  308,

     1308, 1214, 1308, 1163, 1308,  350, 1308,  365, 1308,  257,
      291,  371,  377, 1308,  366, 1308, 1308, 1151, 1158, 1158,
     1146, 1141, 1159, 1146, 1146, 1136, 1151, 1169, 1138, 1148,
     1138,  261, 1131, 1145, 1129, 1144, 1131,  259,  300, 1126,
     1144, 1124, 1128, 1141, 1136, 1137, 1133, 1118, 1119, 1117,
     1114, 1118,  277, 1132, 1127, 1128, 1129, 1124, 1115,  286,
     1122, 1107,    0, 1120, 1106, 1108, 1101, 1112, 1099, 1114,
     1111, 1099, 1115, 1110,    0, 1100, 1108, 1094,    0, 1100,
     1091, 1104, 1094, 1085, 1086, 1093, 1095, 1089, 1081, 1101,
     1084, 1081, 1080, 1083, 1091, 1077, 1074,  290, 1073, 1086,

      319, 1075, 1070, 1070, 1073, 1086, 1081,    0, 1080,  301,
     1066, 1074, 1068, 1061, 1060, 1059, 1074, 1076, 1064, 1068,
     1063,  395,  401,  421,  427, 1308, 1308,  309,  338, 1069,
     1067, 1095,  365, 1062, 1060, 1063, 1074, 1046, 1072,    0,
     1043, 1051, 1042, 1055, 1040, 1041, 1034, 1052, 1051, 1043,
     1040, 1050,  337, 1031, 1037, 1045,    0, 1038,    0, 1040,
     1041, 1028, 1026, 1031, 1034, 1022, 1032, 1019, 1019, 1037,
     1024,    0, 1027, 1017, 1016, 1028, 1018, 1016, 1014, 1015,
     1008, 1026, 1017, 1023, 1005, 1003, 1004, 1020, 1005,    0,
     1007,  998, 1016, 1011, 1006,  995,  993,  994,  998,  998,

     1004,  988, 1002,  991,  992,  348,  990, 1000,  999,  995,
      366,  988,  978,  975,  983,    0,  301,  981,  981,  981,
      986,  985,  976,  985,  968,    0,  968,  982,  973,  985,
     1308,  991,  965,  978,  969,  960,  986,  964,  957,  968,
      985,  954,  953,  979,  978,  964,  964,  947,  947,  948,
      947,  959,  956,  942,  372,  943,  953,  935,    0,  953,
      942,  942,  943,  954,  939,  940,  946,  932,  940,  945,
      927,  932,    0,  941,  923,  924,  937,    0,  263,  917,
      928,  923,  933,  918,  916,  929,  915,    0,  913,  929,
      928,  910,  924,  914,  926,  921,  921,  920,  917,    0,

      920,  918,  913,  899,  910,  912,  391,  915,  897,  907,
      908,  911,  893,    0,    0,  896,  891,  884,  906,  897,
        0,  904,  891,  883,    0,  898,  896,  895,  879,  905,
      879,  895,  894,  876,  903,  884,  871,  885,  913,  885,
      866,  877,  891,  866,    0,  862,  385,  877,  869,  887,
      861,  869,  877,  871,  872,  853,  853,  868,  868,  861,
        0,    0,  853,  860,    0,  857,    0,    0,  861,  864,
      846,  847,  847,  855,  852,  854,  838,  852,  838,    0,
      845,  836,    0,  841,  852,    0,    0,    0,  833,  386,
      830,  844,  836,  841,  833,  832,  839,    0,  824,  830,

      829,  888,  838,  837,  819,  843,  842,  829,  825,  807,
      827,  810,  824,  827,  826,  808,  807,  820,  803,  804,
      795,  819,  423,  801,  384,  443,  813,  809,    0,  812,
      802,    0,  813,  808,    0,    0,  812,  791,    0,  809,
        0,  806,  792,  802,  788,  786,  803,  798,  784,  785,
      785,  449,  784,  795,    0,  411,  792,  456,  791,    0,
      790,    0,  790,  785,  787,  839,  770,  769,  783,  779,
      778,  771,  783,  790,  777,  778,  779,  759,  774,  772,
        0,  772,  754,  769,  768,  754,  756,  750,  764,  434,
      789,  788,  787,  744,  771,  762,    0,  761,  742,    0,

      757,  741,   36,   92,  152,  171,  190,  241,    0,  232,
      270,  344,  347,  376,  364,  396,  417,  421,  443,  450,
      451,  452,  441,  436,    0,  437,    0,  422,  436,  423,
      442,  443,  442,  442,  439,  432,  443,  439,  450,  450,
      455,  439,  440,  491,  444,  456,  451,  464,  462,    0,
      491,  492,    0,  467,  450,  467,  462,  453,  473,  470,
        0,  464,  457,  458,  475,  476,    0,    0,    0,    0,
      505,  463,  473,  466,  518,    0,    0,    0,  510,  484,
      485,  481,    0,  472,  488,  489,  485,  490,  495,    0,
        0,    0,  489,  480,  486,  495,  496,  523,  524,  525,

      516,  501,  491,  488,  533,  493,  494,  520,  509,  497,
      511,  502,  499,  515,  519,  512,    0,  504,  503,  544,
      524,  526,  507,  561,  550,  521,  527,  509,  557,  530,
      531,  525,  520,  535,    0,    0,    0,  521,  537,  566,
      567,    0,  526,  525,  526,  546,  543,  528,  532,  533,
      576,  577,  549,  537,  538,  537,    0,  538,  537,    0,
      560,    0,  541,  543,    0,    0,    0,    0,  545,  612,
      544,  548,  549,  575,    0,  564,  551,  596,  556,  557,
      572,  576,  582,  561,    0,  574,  580,  581,  565,  566,
      584,    0,    0,  577,  582,  585,  584,  570,    0,  639,

      640,  587,    0,    0,  574,  586,  578,  620,  577,  582,
      583,  597,  583,  595,  596,  600,  582,  583,  591,  592,
      598,  597,    0,  612,    0,  613,  663,  601,  602,  612,
      618,  615,    0,  600,  616,  622,  623,  607,  621,  622,
      609,  624,    0,    0,  629,  630,    0,  618,  614,  614,
      623,  613,  632,  618,  616,  634,  635,  617,  619,  640,
        0,  623,  632,  630,  624,  625,    0,  631,  647,  632,
      654,  637,  651,    0,  651,  654,    0,    0,  656,    0,
      647,    0,    0,    0,    0,  649,  650,    0,    0,  659,
      647,  690,  675,  655,  669,  653,    0,  651,  653,  669,

      655,  676,  667,    0,  672,  661,  656,  681,  672,  671,
      681,  667,  669,  670,  690,  674,  688,  691,  674,  691,
      687,  746,  681,  680,  683,    0,  687,  751, 1308,    0,
      683,  700,  688,  690,  741,  761,  709,  736,  737,  738,
      766, 1308,  715,  744,  745,    0,  746,  706,  707,  705,
      710,  711,  724,  730,  731,  727,  709,  710,  731,    0,
        0,  719,    0, 1308,  787,  790,  793,  796,  799,  801,
      804,  806
    } ;

static const flex_int16_t yy_def[1073] =
    {   0,
     1064,    1, 1065, 1065, 1066, 1066, 1067, 1067, 1068, 1068,
     1064, 1064, 1064, 1064, 1064, 1064, 1069, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064,   25, 1064, 1064, 1064, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1064, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1071, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1069, 1064, 1069, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,

       25,   26, 1064, 1064, 1064, 1072, 1064, 1064, 1064, 1064,
     1064, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1064, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1071,

     1064, 1071, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1072, 1064, 1064, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,

     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,

     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1064, 1064,
     1064, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,

     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1064, 1064, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,

     1070, 1064, 1064, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1064, 1064, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,

     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1064, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1064, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,

     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1064, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1064,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1064,

     1064, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1064, 1064, 1064, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1064, 1064, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1064,
     1064, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1064, 1064, 1070, 1070, 1070,
     1070, 1070, 1070, 1064, 1064, 1070, 1070, 1070, 1070, 1070,

     1070, 1064, 1064, 1070, 1070, 1070, 1070, 1070, 1064, 1064,
     1070, 1070, 1070, 1070, 1064, 1064, 1070, 1070, 1070, 1070,
     1064, 1064, 1070, 1070, 1070, 1070, 1064, 1064, 1064, 1070,
     1070, 1070, 1064, 1070, 1070, 1064, 1070, 1070, 1070, 1070,
     1064, 1064, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070, 1070,
     1070, 1070, 1070,    0, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064
    } ;

static const flex_int16_t yy_nxt[1386] =
    {   0,
       12,   13,   14,   15,   16,   17,   12,   18,   19,   12,
       12,   20,   21,   22,   23,   24,   25,   26,   26,   26,
       26,   26,   27,   28,   29,   30,   31,   32,   33,   30,
       30,   34,   35,   36,   30,   37,   30,   38,   39,   40,
       30,   41,   42,   43,   30,   44,   30,   12,   45,   30,
       46,   47,   48,   49,   50,   51,   52,   30,   53,   30,
       30,   54,   55,   56,   57,   58,   30,   59,   60,   61,
       62,   63,   64,   30,   30,   30,   65,   68,   69,   78,
       79,   78,   79,   68,   69,   73,   74,   75,   88,   76,
      761,   70,   70,   70,   70,   70,   70,   70,   70,   70,

       70,   70,   70,   73,   74,   75,   91,   76,   82,   83,
       82,   83,   94,  239,   96,   98,   98,   98,   98,   98,
       98,   92,  130,   95,   97,  102,  102,  102,  102,  102,
       89,  107,  108,  110,  111,  117,  156,  125,  239,  157,
       71,  131,   80,  126,   80,  118,   71,  100,  113,  101,
      101,  101,  101,  101,  102,  127,  762,  114,  132,  128,
      145,  115,  103,  129,  146,  139,  140,  152,  104,  141,
      147,  162,  142,  149,  193,  150,  143,  105,  158,  144,
      148,  153, 1064,  133,  154,  151,  159,  103,  164,  160,
      155,  163,  165,  167,  104,  161,  134,  169,  168,  174,

      176,  132,  166,  105,  763,  170,  106,  177,  178,  175,
      187,  171,  201,  179,  172,  188,   88,  173,  214,  180,
      189,  214,  181,  182,  190,  764,  183,  194,  239,  184,
      191,  196,  196,  196,  196,  196,  196,  245,  246,  185,
      232,  210,  254,  765,  214,  260,  186,  214,  255,  261,
      211,  314,  268,  239,  202,  269,  233,  234,   89,   98,
       98,   98,   98,   98,   98,  284,  315,  210,  251,  252,
      253,  285,  206,  207,  240,  207,  211,  212,  212, 1064,
      276,  213,  213,  213,  213,  213,  213,  277,  280,  287,
      294,  288,  292,  297,  275,  306,  304,  206,  207,  766,

      207,  326,  289,  239,  281,  305,  293,  307,  310,  295,
      298,  308,  317,  201,  311,  318,  566,  351,  312,  207,
       98,   98,   98,   98,   98,   98,  326,  326,  301,  352,
      567,  344,  353,  208,  209,  345,  209,  767,  302,  196,
      196,  196,  196,  196,  196,  366,  367,  373,  407,  303,
      374,  353,  326,  431,  511,  202,  418,  353,  208,  209,
      408,  209,  322,  322,  512,  419,  323,  323,  323,  323,
      323,  323,  768,  431,  455,  769,  411,  324,  324,  431,
      209,  325,  325,  325,  325,  325,  325,  213,  213,  213,
      213,  213,  213,  213,  213,  213,  213,  213,  213,  431,

      455,  328,  501,  455,  770,  547,  502,  327,  771,  327,
      329,  323,  323,  323,  323,  323,  323,  323,  323,  323,
      323,  323,  323,  435,  547,  625,  625,  328,  690,  507,
      547,  207,  327,  207,  327,  436,  329,  325,  325,  325,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  590,
      687,  625,  656,  327,  690,  690,  207,  209,  207,  209,
      691,  692,  693,  750,  772,  688,  712,  713,  714,  773,
      694,  774,  750,  720,  721,  722,  715,  207,  776,  777,
      778,  719,  209,  723,  209,  779,  780,  781,  750,  782,
      783,  784,  785,  786,  787,  788,  789,  775,  716,  790,

      791,  792,  793,  209,  794,  795,  796,  797,  798,  799,
      800,  801,  802,  803,  804,  805,  806,  807,  809,  810,
      811,  812,  357,  813,  814,  815,  816,  817,  808,  818,
      819,  820,  821,  822,  823,  824,  825,  826,  827,  828,
      829,  830,  831,  832,  833,  834,  835,  836,  837,  838,
      839,  840,  841,  842,  843,  845,  846,  847,  844,  848,
      849,  850,  851,  852,  853,  854,  855,  856,  857,  858,
      859,  860,  861,  862,  863,  864,  308,  865,  866,  867,
      868,  869,  870,  871,  872,  873,  874,  875,  876,  877,
      878,  879,  880,  881,  882,  883,  884,  885,  886,  887,

      888,  889,  890,  891,  892,  893,  357,  894,  895,  896,
      897,  898,  899,  900,  902,  903,  904,  905,  907,  908,
      906,  901,  909,  910,  911,  912,  913,  914,  915,  916,
      917,  918,  919,  920,  921,  922,  923,  924,  925,  926,
      900,  927,  930,  931,  932,  933,  934,  935,  901,  936,
      937,  938,  939,  940,  941,  942,  943,  944,  945,  946,
      947,  948,  949,  950,  927,  951,  952,  953,  954,  955,
      956,  957,  958,  959,  960,  961,  962,  963,  964,  965,
      966,  967,  968,  969,  970,  971,  972,  973,  974,  975,
      976,  977,  928,  978,  979,  980,  981,  982,  983,  984,

      308,  985,  986,  987,  988,  989,  990,  929,  991,  992,
      993,  994,  995,  996,  997,  928,  998, 1001, 1002, 1003,
     1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011, 1012, 1013,
      929, 1014,  999, 1000, 1015, 1016, 1017, 1018, 1019, 1020,
     1021, 1022, 1023, 1024, 1025, 1026, 1027, 1028, 1030, 1031,
     1032, 1033, 1028, 1034, 1035, 1036, 1029, 1037, 1038, 1039,
     1040, 1029, 1041, 1043, 1044, 1045, 1046, 1041, 1047, 1048,
     1049, 1042, 1050, 1051, 1052, 1053, 1042, 1054, 1055, 1056,
     1057, 1058, 1059, 1060, 1061, 1062, 1063,   67,   67,   67,
       72,   72,   72,   77,   77,   77,   81,   81,   81,   87,

       87,   87,  112,  112,  200,  200,  200,  215,  760,  759,
      758,  757,  756,  755,  754,  753,  752,  751,  749,  748,
      747,  746,  745,  744,  743,  742,  741,  740,  739,  738,
      737,  736,  735,  734,  733,  732,  731,  730,  729,  728,
      666,  727,  726,  725,  514,  724,  308,  718,  717,  711,
      710,  709,  708,  707,  706,  275,  705,  704,  703,  702,
      275,  701,  700,  699,  698,  697,  696,  695,  689,  686,
      685,  684,  683,  682,  681,  680,  679,  678,  677,  676,
      675,  674,  673,  672,  671,  670,  669,  668,  667,  666,
      665,  514,  664,  663,  662,  661,  660,  659,  658,  657,

      655,  654,  653,  652,  651,  650,  649,  648,  275,  647,
      646,  645,  644,  643,  642,  275,  641,  640,  639,  638,
      637,  636,  635,  634,  633,  632,  631,  630,  629,  628,
      627,  626,  624,  623,  622,  621,  620,  619,  618,  617,
      616,  615,  614,  613,  612,  611,  610,  609,  608,  607,
      606,  605,  604,  603,  602,  601,  600,  599,  598,  597,
      596,  595,  594,  593,  592,  591,  589,  588,  587,  586,
      585,  584,  308,  308,  583,  582,  581,  580,  579,  578,
      275,  577,  576,  575,  574,  573,  572,  571,  570,  569,
      568,  565,  564,  563,  275,  562,  561,  560,  559,  558,

      357,  557,  556,  555,  554,  553,  552,  551,  550,  549,
      548,  546,  545,  544,  543,  542,  541,  540,  539,  538,
      537,  536,  535,  534,  533,  532,  531,  530,  529,  528,
      527,  526,  525,  524,  523,  522,  521,  520,  519,  518,
      517,  514,  516,  515,  514,  513,  510,  308,  509,  508,
      506,  505,  504,  503,  500,  499,  498,  308,  497,  496,
      495,  494,  493,  492,  491,  490,  489,  488,  487,  486,
      485,  484,  483,  482,  481,  480,  479,  478,  477,  476,
      475,  474,  473,  472,  471,  470,  469,  468,  467,  466,
      465,  464,  463,  462,  357,  461,  460,  357,  459,  458,

      457,  456,  454,  453,  452,  451,  450,  449,  448,  447,
      446,  445,  444,  443,  442,  441,  440,  439,  438,  437,
      434,  433,  432,  430,  429,  428,  427,  426,  425,  424,
      423,  422,  421,  420,  417,  416,  415,  414,  308,  413,
      412,  410,  409,  406,  405,  404,  403,  402,  401,  400,
      399,  398,  397,  396,  395,  394,  393,  392,  391,  390,
      389,  388,  387,  386,  385,  384,  383,  275,  382,  381,
      380,  379,  275,  378,  377,  376,  375,  357,  372,  371,
      370,  369,  368,  365,  364,  363,  357,  362,  361,  360,
      359,  358,  357,  356,  355,  354,  350,  349,  348,  347,

      346,  343,  342,  341,  340,  339,  338,  337,  336,  335,
      334,  333,  332,  331,  330,  321, 1064,  198,  320,  319,
      316,  313,  309,  300,  299,  296,  291,  290,  286,  283,
      282,  279,  278,  275,  274,  273,  272,  271,  270,  267,
      266,  265,  264,  263,  262,  259,  258,  257,  256,  250,
      249,  248,  247,  244,  243,  242,  241,  238,  237,  236,
      235,  231,  230,  229,  228,  227,  226,  225,  224,  223,
      222,  221,  220,  219,  218,  217,  216, 1064,   84,  205,
      204,  203,  199,  198,  197,  195,  192,  138,  137,  136,
      135,  124,  123,  122,  121,  120,  119,  116,  109,   99,

       93,   90,   86,   85,   84, 1064,   66,   11, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064
    } ;

static const flex_int16_t yy_chk[1386] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    3,    3,    7,
        7,    8,    8,    4,    4,    5,    5,    5,   17,    5,
      703,    3,    3,    3,    3,    3,    3,    4,    4,    4,

        4,    4,    4,    6,    6,    6,   19,    6,    9,    9,
       10,   10,   21,  132,   22,   23,   23,   23,   23,   23,
       23,   19,   42,   21,   22,   26,   26,   26,   26,   26,
       17,   27,   27,   29,   29,   33,   52,   40,  132,   52,
        3,   42,    7,   40,    8,   33,    4,   25,   31,   25,
       25,   25,   25,   25,   25,   41,  704,   31,   43,   41,
       49,   31,   25,   41,   49,   48,   48,   51,   25,   48,
       49,   55,   48,   50,   65,   50,   48,   25,   53,   48,
       49,   51,   26,   43,   51,   50,   53,   25,   56,   54,
       51,   55,   56,   57,   25,   54,   43,   58,   57,   59,

       60,   61,   56,   25,  705,   58,   25,   60,   60,   59,
       62,   58,   76,   60,   58,   62,   87,   58,  104,   60,
       63,  105,   60,   61,   63,  706,   61,   65,  133,   61,
       63,   70,   70,   70,   70,   70,   70,  139,  139,   61,
      127,  101,  145,  707,  104,  151,   61,  105,  145,  151,
      101,  189,  159,  133,   76,  159,  127,  127,   87,   98,
       98,   98,   98,   98,   98,  172,  189,  101,  144,  144,
      144,  172,   98,   98,  133,   98,  101,  103,  103,  101,
      166,  103,  103,  103,  103,  103,  103,  166,  169,  174,
      178,  174,  177,  180,  708,  185,  184,   98,   98,  710,

       98,  210,  174,  183,  169,  184,  177,  185,  187,  178,
      180,  185,  191,  200,  187,  191,  479,  238,  187,   98,
      100,  100,  100,  100,  100,  100,  211,  210,  183,  238,
      479,  232,  239,  100,  100,  232,  100,  711,  183,  196,
      196,  196,  196,  196,  196,  253,  253,  260,  298,  183,
      260,  301,  211,  328,  417,  200,  310,  239,  100,  100,
      298,  100,  206,  206,  417,  310,  206,  206,  206,  206,
      206,  206,  712,  329,  353,  713,  301,  208,  208,  328,
      100,  208,  208,  208,  208,  208,  208,  212,  212,  212,
      212,  212,  212,  213,  213,  213,  213,  213,  213,  329,

      353,  215,  406,  411,  714,  455,  406,  213,  715,  213,
      215,  322,  322,  322,  322,  322,  322,  323,  323,  323,
      323,  323,  323,  333,  507,  547,  590,  215,  625,  411,
      455,  323,  213,  323,  213,  333,  215,  324,  324,  324,
      324,  324,  324,  325,  325,  325,  325,  325,  325,  507,
      623,  547,  590,  213,  625,  656,  323,  325,  323,  325,
      626,  626,  626,  690,  716,  623,  652,  652,  652,  717,
      626,  718,  719,  658,  658,  658,  652,  323,  720,  721,
      722,  656,  325,  658,  325,  723,  724,  726,  690,  728,
      729,  730,  731,  732,  733,  734,  735,  719,  652,  736,

      737,  738,  739,  325,  740,  741,  742,  743,  744,  744,
      744,  745,  746,  747,  748,  749,  751,  752,  754,  755,
      756,  757,  758,  759,  760,  762,  763,  764,  752,  765,
      766,  771,  772,  773,  774,  775,  779,  780,  781,  782,
      784,  785,  786,  787,  788,  789,  793,  794,  795,  796,
      797,  798,  799,  800,  801,  802,  803,  804,  801,  805,
      806,  807,  808,  809,  810,  811,  812,  813,  814,  815,
      816,  818,  819,  820,  821,  822,  823,  824,  824,  825,
      826,  827,  828,  829,  830,  831,  832,  833,  834,  838,
      839,  840,  841,  843,  844,  845,  846,  847,  848,  849,

      850,  851,  852,  853,  854,  855,  856,  858,  859,  861,
      863,  864,  869,  870,  871,  872,  873,  874,  876,  877,
      874,  870,  878,  879,  880,  881,  882,  883,  884,  886,
      887,  888,  889,  890,  891,  894,  895,  896,  897,  898,
      900,  901,  902,  905,  906,  907,  908,  909,  900,  910,
      911,  912,  913,  914,  915,  916,  917,  918,  919,  920,
      921,  922,  924,  926,  927,  928,  929,  930,  931,  932,
      934,  935,  936,  937,  938,  939,  940,  941,  942,  945,
      946,  948,  949,  950,  951,  952,  953,  954,  955,  956,
      957,  958,  901,  959,  960,  962,  963,  964,  965,  966,

      968,  969,  970,  971,  972,  973,  975,  901,  976,  979,
      981,  986,  987,  990,  991,  927,  992,  993,  994,  995,
      996,  998,  999, 1000, 1001, 1002, 1003, 1005, 1006, 1007,
      927, 1008,  992,  992, 1009, 1010, 1011, 1012, 1013, 1014,
     1015, 1016, 1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024,
     1025, 1027, 1028, 1031, 1032, 1033, 1022, 1034, 1035, 1035,
     1035, 1028, 1036, 1037, 1038, 1039, 1040, 1041, 1043, 1044,
     1045, 1036, 1047, 1048, 1049, 1050, 1041, 1051, 1052, 1053,
     1054, 1055, 1056, 1057, 1058, 1059, 1062, 1065, 1065, 1065,
     1066, 1066, 1066, 1067, 1067, 1067, 1068, 1068, 1068, 1069,

     1069, 1069, 1070, 1070, 1071, 1071, 1071, 1072,  702,  701,
      699,  698,  696,  695,  694,  693,  692,  691,  689,  688,
      687,  686,  685,  684,  683,  682,  680,  679,  678,  677,
      676,  675,  674,  673,  672,  671,  670,  669,  668,  667,
      666,  665,  664,  663,  661,  659,  657,  654,  653,  651,
      650,  649,  648,  647,  646,  645,  644,  643,  642,  640,
      638,  637,  634,  633,  631,  630,  628,  627,  624,  622,
      621,  620,  619,  618,  617,  616,  615,  614,  613,  612,
      611,  610,  609,  608,  607,  606,  605,  604,  603,  602,
      601,  600,  599,  597,  596,  595,  594,  593,  592,  591,

      589,  585,  584,  582,  581,  579,  578,  577,  576,  575,
      574,  573,  572,  571,  570,  569,  566,  564,  563,  560,
      559,  558,  557,  556,  555,  554,  553,  552,  551,  550,
      549,  548,  546,  544,  543,  542,  541,  540,  539,  538,
      537,  536,  535,  534,  533,  532,  531,  530,  529,  528,
      527,  526,  524,  523,  522,  520,  519,  518,  517,  516,
      513,  512,  511,  510,  509,  508,  506,  505,  504,  503,
      502,  501,  499,  498,  497,  496,  495,  494,  493,  492,
      491,  490,  489,  487,  486,  485,  484,  483,  482,  481,
      480,  477,  476,  475,  474,  472,  471,  470,  469,  468,

      467,  466,  465,  464,  463,  462,  461,  460,  458,  457,
      456,  454,  453,  452,  451,  450,  449,  448,  447,  446,
      445,  444,  443,  442,  441,  440,  439,  438,  437,  436,
      435,  434,  433,  432,  430,  429,  428,  427,  425,  424,
      423,  422,  421,  420,  419,  418,  415,  414,  413,  412,
      410,  409,  408,  407,  405,  404,  403,  402,  401,  400,
      399,  398,  397,  396,  395,  394,  393,  392,  391,  389,
      388,  387,  386,  385,  384,  383,  382,  381,  380,  379,
      378,  377,  376,  375,  374,  373,  371,  370,  369,  368,
      367,  366,  365,  364,  363,  362,  361,  360,  358,  356,

      355,  354,  352,  351,  350,  349,  348,  347,  346,  345,
      344,  343,  342,  341,  339,  338,  337,  336,  335,  334,
      332,  331,  330,  321,  320,  319,  318,  317,  316,  315,
      314,  313,  312,  311,  309,  307,  306,  305,  304,  303,
      302,  300,  299,  297,  296,  295,  294,  293,  292,  291,
      290,  289,  288,  287,  286,  285,  284,  283,  282,  281,
      280,  278,  277,  276,  274,  273,  272,  271,  270,  269,
      268,  267,  266,  265,  264,  262,  261,  259,  258,  257,
      256,  255,  254,  252,  251,  250,  249,  248,  247,  246,
      245,  244,  243,  242,  241,  240,  237,  236,  235,  234,

      233,  231,  230,  229,  228,  227,  226,  225,  224,  223,
      222,  221,  220,  219,  218,  204,  202,  198,  197,  192,
      190,  188,  186,  182,  181,  179,  176,  175,  173,  171,
      170,  168,  167,  165,  164,  163,  162,  161,  160,  157,
      156,  155,  154,  153,  152,  150,  149,  148,  146,  143,
      142,  141,  140,  138,  137,  135,  134,  131,  130,  129,
      128,  126,  125,  124,  123,  122,  121,  120,  119,  118,
      117,  116,  115,  114,  113,  111,  107,   89,   84,   83,
       80,   79,   75,   73,   71,   69,   64,   47,   46,   45,
       44,   39,   38,   37,   36,   35,   34,   32,   28,   24,

       20,   18,   16,   15,   13,   11,    2, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064, 1064,
     1064, 1064, 1064, 1064, 1064
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "libs/vkd3d-shader/hlsl.l"
/*
 * HLSL parser
 *
 * Copyright 2008 Stefan Dösinger
 * Copyright 2012 Matteo Bruni for CodeWeavers
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
#line 23 "libs/vkd3d-shader/hlsl.l"
#define YY_NO_UNISTD_H
#include "hlsl.h"
#include "hlsl.tab.h"

#define YYSTYPE HLSL_YYSTYPE
#define YYLTYPE HLSL_YYLTYPE

static void update_location(struct hlsl_ctx *ctx, YYLTYPE *loc);

static void apply_escape_sequences(char *str);

#define YY_USER_ACTION update_location(yyget_extra(yyscanner), yyget_lloc(yyscanner));

#line 1348 "libs/vkd3d-shader/hlsl.yy.c"
#define YY_NO_INPUT 1

#line 1351 "libs/vkd3d-shader/hlsl.yy.c"

#define INITIAL 0
#define pp 1
#define pp_line 2
#define pp_pragma 3
#define pp_ignore 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE struct hlsl_ctx *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

       YYLTYPE *yyget_lloc ( yyscan_t yyscanner );
    
        void yyset_lloc ( YYLTYPE * yylloc_param , yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 63 "libs/vkd3d-shader/hlsl.l"

#line 1640 "libs/vkd3d-shader/hlsl.yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1065 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 1064 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
#line 65 "libs/vkd3d-shader/hlsl.l"
case 2:
#line 66 "libs/vkd3d-shader/hlsl.l"
case 3:
#line 67 "libs/vkd3d-shader/hlsl.l"
case 4:
YY_RULE_SETUP
#line 67 "libs/vkd3d-shader/hlsl.l"
{
                            struct hlsl_ctx *ctx = yyget_extra(yyscanner);

                            hlsl_error(ctx, yylloc, VKD3D_SHADER_ERROR_HLSL_INVALID_SYNTAX,
                                    "Reserved keyword \"%s\" used.", yytext);
                        }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 74 "libs/vkd3d-shader/hlsl.l"
{return KW_BLENDSTATE;          }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 75 "libs/vkd3d-shader/hlsl.l"
{return KW_BREAK;               }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 76 "libs/vkd3d-shader/hlsl.l"
{return KW_BUFFER;              }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 77 "libs/vkd3d-shader/hlsl.l"
{return KW_BYTEADDRESSBUFFER;   }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 78 "libs/vkd3d-shader/hlsl.l"
{return KW_CASE;                }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 79 "libs/vkd3d-shader/hlsl.l"
{return KW_CBUFFER;             }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 80 "libs/vkd3d-shader/hlsl.l"
{return KW_CENTROID;            }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 81 "libs/vkd3d-shader/hlsl.l"
{return KW_COLUMN_MAJOR;        }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 82 "libs/vkd3d-shader/hlsl.l"
{return KW_COMPUTESHADER;       }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 83 "libs/vkd3d-shader/hlsl.l"
{return KW_COMPILE;             }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 84 "libs/vkd3d-shader/hlsl.l"
{return KW_COMPILESHADER;       }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 85 "libs/vkd3d-shader/hlsl.l"
{return KW_CONST;               }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 86 "libs/vkd3d-shader/hlsl.l"
{return KW_CONTINUE;            }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 87 "libs/vkd3d-shader/hlsl.l"
{return KW_DEPTHSTENCILSTATE;   }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 88 "libs/vkd3d-shader/hlsl.l"
{return KW_DEPTHSTENCILVIEW;    }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 89 "libs/vkd3d-shader/hlsl.l"
{return KW_DEFAULT;             }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 90 "libs/vkd3d-shader/hlsl.l"
{return KW_DISCARD;             }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 91 "libs/vkd3d-shader/hlsl.l"
{return KW_DOMAINSHADER;        }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 92 "libs/vkd3d-shader/hlsl.l"
{return KW_DO;                  }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 93 "libs/vkd3d-shader/hlsl.l"
{return KW_ELSE;                }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 94 "libs/vkd3d-shader/hlsl.l"
{return KW_EXPORT;              }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 95 "libs/vkd3d-shader/hlsl.l"
{return KW_EXTERN;              }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 96 "libs/vkd3d-shader/hlsl.l"
{return KW_FALSE;               }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 97 "libs/vkd3d-shader/hlsl.l"
{return KW_FOR;                 }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 98 "libs/vkd3d-shader/hlsl.l"
{return KW_FXGROUP;             }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 99 "libs/vkd3d-shader/hlsl.l"
{return KW_GEOMETRYSHADER;      }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 100 "libs/vkd3d-shader/hlsl.l"
{return KW_GROUPSHARED;         }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 101 "libs/vkd3d-shader/hlsl.l"
{return KW_HULLSHADER;          }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 102 "libs/vkd3d-shader/hlsl.l"
{return KW_IF;                  }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 103 "libs/vkd3d-shader/hlsl.l"
{return KW_IN;                  }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 104 "libs/vkd3d-shader/hlsl.l"
{return KW_INLINE;              }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 105 "libs/vkd3d-shader/hlsl.l"
{return KW_INOUT;               }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 106 "libs/vkd3d-shader/hlsl.l"
{return KW_INPUTPATCH;          }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 107 "libs/vkd3d-shader/hlsl.l"
{return KW_LINESTREAM;          }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 108 "libs/vkd3d-shader/hlsl.l"
{return KW_LINE;                }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 109 "libs/vkd3d-shader/hlsl.l"
{return KW_LINEADJ;             }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 110 "libs/vkd3d-shader/hlsl.l"
{return KW_LINEAR;              }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 111 "libs/vkd3d-shader/hlsl.l"
{return KW_MATRIX;              }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 112 "libs/vkd3d-shader/hlsl.l"
{return KW_NAMESPACE;           }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 113 "libs/vkd3d-shader/hlsl.l"
{return KW_NOINTERPOLATION;     }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 114 "libs/vkd3d-shader/hlsl.l"
{return KW_NOPERSPECTIVE;       }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 115 "libs/vkd3d-shader/hlsl.l"
{return KW_NULL;                }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 116 "libs/vkd3d-shader/hlsl.l"
{return KW_OUT;                 }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 117 "libs/vkd3d-shader/hlsl.l"
{return KW_OUTPUTPATCH;         }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 118 "libs/vkd3d-shader/hlsl.l"
{return KW_PACKOFFSET;          }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 119 "libs/vkd3d-shader/hlsl.l"
{return KW_PASS;                }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 120 "libs/vkd3d-shader/hlsl.l"
{return KW_PIXELSHADER;         }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 121 "libs/vkd3d-shader/hlsl.l"
{return KW_POINTSTREAM;         }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 122 "libs/vkd3d-shader/hlsl.l"
{return KW_PIXELSHADER;         }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 123 "libs/vkd3d-shader/hlsl.l"
{return KW_POINT;               }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 124 "libs/vkd3d-shader/hlsl.l"
{return KW_RASTERIZERORDEREDBUFFER;            }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 125 "libs/vkd3d-shader/hlsl.l"
{return KW_RASTERIZERORDEREDSTRUCTUREDBUFFER;  }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 126 "libs/vkd3d-shader/hlsl.l"
{return KW_RASTERIZERORDEREDTEXTURE1D;         }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 127 "libs/vkd3d-shader/hlsl.l"
{return KW_RASTERIZERORDEREDTEXTURE1DARRAY;    }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 128 "libs/vkd3d-shader/hlsl.l"
{return KW_RASTERIZERORDEREDTEXTURE2D;         }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 129 "libs/vkd3d-shader/hlsl.l"
{return KW_RASTERIZERORDEREDTEXTURE2DARRAY;    }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 130 "libs/vkd3d-shader/hlsl.l"
{return KW_RASTERIZERORDEREDTEXTURE3D;         }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 131 "libs/vkd3d-shader/hlsl.l"
{return KW_RASTERIZERSTATE;     }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 132 "libs/vkd3d-shader/hlsl.l"
{return KW_REGISTER;            }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 133 "libs/vkd3d-shader/hlsl.l"
{return KW_RENDERTARGETVIEW;    }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 134 "libs/vkd3d-shader/hlsl.l"
{return KW_RETURN;              }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 135 "libs/vkd3d-shader/hlsl.l"
{return KW_ROW_MAJOR;           }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 136 "libs/vkd3d-shader/hlsl.l"
{return KW_RWBUFFER;            }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 137 "libs/vkd3d-shader/hlsl.l"
{return KW_RWBYTEADDRESSBUFFER; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 138 "libs/vkd3d-shader/hlsl.l"
{return KW_RWSTRUCTUREDBUFFER;  }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 139 "libs/vkd3d-shader/hlsl.l"
{return KW_RWTEXTURE1D;         }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 140 "libs/vkd3d-shader/hlsl.l"
{return KW_RWTEXTURE1DARRAY;    }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 141 "libs/vkd3d-shader/hlsl.l"
{return KW_RWTEXTURE2D;         }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 142 "libs/vkd3d-shader/hlsl.l"
{return KW_RWTEXTURE2DARRAY;    }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 143 "libs/vkd3d-shader/hlsl.l"
{return KW_RWTEXTURE3D;         }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 144 "libs/vkd3d-shader/hlsl.l"
{return KW_SAMPLER;             }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 145 "libs/vkd3d-shader/hlsl.l"
{return KW_SAMPLER1D;           }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 146 "libs/vkd3d-shader/hlsl.l"
{return KW_SAMPLER2D;           }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 147 "libs/vkd3d-shader/hlsl.l"
{return KW_SAMPLER3D;           }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 148 "libs/vkd3d-shader/hlsl.l"
{return KW_SAMPLERCOMPARISONSTATE;}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 149 "libs/vkd3d-shader/hlsl.l"
{return KW_SAMPLERCUBE;         }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 150 "libs/vkd3d-shader/hlsl.l"
{return KW_SAMPLER;             }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 151 "libs/vkd3d-shader/hlsl.l"
{return KW_SAMPLER_STATE;       }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 152 "libs/vkd3d-shader/hlsl.l"
{return KW_SHARED;              }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 153 "libs/vkd3d-shader/hlsl.l"
{return KW_SNORM;               }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 154 "libs/vkd3d-shader/hlsl.l"
{return KW_STATEBLOCK;          }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 155 "libs/vkd3d-shader/hlsl.l"
{return KW_STATEBLOCK_STATE;    }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 156 "libs/vkd3d-shader/hlsl.l"
{return KW_STATIC;              }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 157 "libs/vkd3d-shader/hlsl.l"
{return KW_STRING;              }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 158 "libs/vkd3d-shader/hlsl.l"
{return KW_STRING;              }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 159 "libs/vkd3d-shader/hlsl.l"
{return KW_STRUCT;              }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 160 "libs/vkd3d-shader/hlsl.l"
{return KW_STRUCTUREDBUFFER;    }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 161 "libs/vkd3d-shader/hlsl.l"
{return KW_SWITCH;              }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 162 "libs/vkd3d-shader/hlsl.l"
{return KW_TBUFFER;             }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 163 "libs/vkd3d-shader/hlsl.l"
{return KW_TECHNIQUE;           }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 164 "libs/vkd3d-shader/hlsl.l"
{return KW_TECHNIQUE10;         }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 165 "libs/vkd3d-shader/hlsl.l"
{return KW_TECHNIQUE11;         }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 166 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE;             }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 167 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE1D;           }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 168 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE1D;           }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 169 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE1DARRAY;      }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 170 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE2D;           }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 171 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE2D;           }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 172 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE2DARRAY;      }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 173 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE2DMS;         }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 174 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE2DMSARRAY;    }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 175 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE3D;           }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 176 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURE3D;           }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 177 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURECUBE;         }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 178 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURECUBE;         }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 179 "libs/vkd3d-shader/hlsl.l"
{return KW_TEXTURECUBEARRAY;    }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 180 "libs/vkd3d-shader/hlsl.l"
{return KW_TRIANGLESTREAM;      }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 181 "libs/vkd3d-shader/hlsl.l"
{return KW_TRIANGLE;            }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 182 "libs/vkd3d-shader/hlsl.l"
{return KW_TRIANGLEADJ;         }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 183 "libs/vkd3d-shader/hlsl.l"
{return KW_TRUE;                }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 184 "libs/vkd3d-shader/hlsl.l"
{return KW_TYPEDEF;             }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 185 "libs/vkd3d-shader/hlsl.l"
{return KW_UNSIGNED;            }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 186 "libs/vkd3d-shader/hlsl.l"
{return KW_UNIFORM;             }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 187 "libs/vkd3d-shader/hlsl.l"
{return KW_UNORM;               }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 188 "libs/vkd3d-shader/hlsl.l"
{return KW_VECTOR;              }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 189 "libs/vkd3d-shader/hlsl.l"
{return KW_VERTEXSHADER;        }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 190 "libs/vkd3d-shader/hlsl.l"
{return KW_VERTEXSHADER;        }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 191 "libs/vkd3d-shader/hlsl.l"
{return KW_VOID;                }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 192 "libs/vkd3d-shader/hlsl.l"
{return KW_VOLATILE;            }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 193 "libs/vkd3d-shader/hlsl.l"
{return KW_WHILE;               }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 195 "libs/vkd3d-shader/hlsl.l"
{return OP_INC;                 }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 196 "libs/vkd3d-shader/hlsl.l"
{return OP_DEC;                 }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 197 "libs/vkd3d-shader/hlsl.l"
{return OP_AND;                 }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 198 "libs/vkd3d-shader/hlsl.l"
{return OP_OR;                  }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 199 "libs/vkd3d-shader/hlsl.l"
{return OP_EQ;                  }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 200 "libs/vkd3d-shader/hlsl.l"
{return OP_LEFTSHIFT;           }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 201 "libs/vkd3d-shader/hlsl.l"
{return OP_LEFTSHIFTASSIGN;     }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 202 "libs/vkd3d-shader/hlsl.l"
{return OP_RIGHTSHIFT;          }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 203 "libs/vkd3d-shader/hlsl.l"
{return OP_RIGHTSHIFTASSIGN;    }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 204 "libs/vkd3d-shader/hlsl.l"
{return OP_LE;                  }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 205 "libs/vkd3d-shader/hlsl.l"
{return OP_GE;                  }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 206 "libs/vkd3d-shader/hlsl.l"
{return OP_NE;                  }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 207 "libs/vkd3d-shader/hlsl.l"
{return OP_ADDASSIGN;           }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 208 "libs/vkd3d-shader/hlsl.l"
{return OP_SUBASSIGN;           }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 209 "libs/vkd3d-shader/hlsl.l"
{return OP_MULASSIGN;           }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 210 "libs/vkd3d-shader/hlsl.l"
{return OP_DIVASSIGN;           }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 211 "libs/vkd3d-shader/hlsl.l"
{return OP_MODASSIGN;           }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 212 "libs/vkd3d-shader/hlsl.l"
{return OP_ANDASSIGN;           }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 213 "libs/vkd3d-shader/hlsl.l"
{return OP_ORASSIGN;            }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 214 "libs/vkd3d-shader/hlsl.l"
{return OP_XORASSIGN;           }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 216 "libs/vkd3d-shader/hlsl.l"
{
                            struct hlsl_ctx *ctx = yyget_extra(yyscanner);

                            if (hlsl_version_ge(ctx, 5, 1) && !strcmp(yytext, "ConstantBuffer"))
                                return KW_CONSTANTBUFFER;

                            yylval->name = hlsl_strdup(ctx, yytext);
                            if (hlsl_get_var(ctx->cur_scope, yytext) || hlsl_get_function(ctx, yytext))
                                return VAR_IDENTIFIER;
                            if (hlsl_get_type(ctx->cur_scope, yytext, true, true))
                                return TYPE_IDENTIFIER;
                            return NEW_IDENTIFIER;
                        }
	YY_BREAK
case 146:
/* rule 146 can match eol */
YY_RULE_SETUP
#line 230 "libs/vkd3d-shader/hlsl.l"
{
                            struct hlsl_ctx *ctx = yyget_extra(yyscanner);
                            char *string = hlsl_strdup(ctx, yytext + 1);

                            string[strlen(string) - 1] = 0;
                            apply_escape_sequences(string);
                            yylval->name = string;
                            return STRING;
                        }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 240 "libs/vkd3d-shader/hlsl.l"
{
                            yylval->floatval = atof(yytext);
                            return C_FLOAT;
                        }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 244 "libs/vkd3d-shader/hlsl.l"
{
                            yylval->floatval = atof(yytext);
                            return C_FLOAT;
                        }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 248 "libs/vkd3d-shader/hlsl.l"
{
                            yylval->floatval = atof(yytext);
                            return C_FLOAT;
                        }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 252 "libs/vkd3d-shader/hlsl.l"
{
                            yylval->intval = vkd3d_parse_integer(yytext);
                            return C_INTEGER;
                        }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 256 "libs/vkd3d-shader/hlsl.l"
{
                            yylval->intval = vkd3d_parse_integer(yytext);
                            return C_INTEGER;
                        }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 260 "libs/vkd3d-shader/hlsl.l"
{
                            yylval->intval = vkd3d_parse_integer(yytext);
                            return C_INTEGER;
                        }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 264 "libs/vkd3d-shader/hlsl.l"
{
                            yylval->intval = vkd3d_parse_integer(yytext);
                            return C_UNSIGNED;
                        }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 268 "libs/vkd3d-shader/hlsl.l"
{
                            yylval->intval = vkd3d_parse_integer(yytext);
                            return C_UNSIGNED;
                        }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 272 "libs/vkd3d-shader/hlsl.l"
{
                            yylval->intval = vkd3d_parse_integer(yytext);
                            return C_UNSIGNED;
                        }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 277 "libs/vkd3d-shader/hlsl.l"
{}
	YY_BREAK
case 157:
/* rule 157 can match eol */
YY_RULE_SETUP
#line 278 "libs/vkd3d-shader/hlsl.l"
{
                            struct hlsl_ctx *ctx = yyget_extra(yyscanner);

                            ++ctx->location.line;
                            ctx->location.column = 1;
                        }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 285 "libs/vkd3d-shader/hlsl.l"
{
                            BEGIN(pp);
                        }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 289 "libs/vkd3d-shader/hlsl.l"
{
                            BEGIN(pp_pragma);
                        }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 292 "libs/vkd3d-shader/hlsl.l"
{
                            struct hlsl_ctx *ctx = yyget_extra(yyscanner);

                            TRACE("#pragma setting row_major mode.\n");
                            ctx->matrix_majority = HLSL_MODIFIER_ROW_MAJOR;
                            BEGIN(pp_ignore);
                        }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 299 "libs/vkd3d-shader/hlsl.l"
{
                            struct hlsl_ctx *ctx = yyget_extra(yyscanner);

                            TRACE("#pragma setting column_major mode.\n");
                            ctx->matrix_majority = HLSL_MODIFIER_COLUMN_MAJOR;
                            BEGIN(pp_ignore);
                        }
	YY_BREAK
case 162:
/* rule 162 can match eol */
YY_RULE_SETUP
#line 306 "libs/vkd3d-shader/hlsl.l"
{
                            struct hlsl_ctx *ctx = yyget_extra(yyscanner);

                            FIXME("Unsupported preprocessor #pragma directive at line %u.\n", ctx->location.line);
                            BEGIN(INITIAL);
                        }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 312 "libs/vkd3d-shader/hlsl.l"
{}
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 313 "libs/vkd3d-shader/hlsl.l"
{
                            BEGIN(pp_line);
                            yylval->intval = (atoi(yytext));
                            return PRE_LINE;
                        }
	YY_BREAK
case 165:
/* rule 165 can match eol */
YY_RULE_SETUP
#line 318 "libs/vkd3d-shader/hlsl.l"
{
                            struct hlsl_ctx *ctx = yyget_extra(yyscanner);
                            char *string = hlsl_strdup(ctx, yytext + 1);

                            BEGIN(pp_ignore);
                            string[strlen(string) - 1] = 0;
                            apply_escape_sequences(string);
                            yylval->name = string;
                            return STRING;
                        }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 328 "libs/vkd3d-shader/hlsl.l"
{}
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 329 "libs/vkd3d-shader/hlsl.l"
{
                            FIXME("Malformed preprocessor line directive?\n");
                            BEGIN(INITIAL);
                        }
	YY_BREAK
case 168:
/* rule 168 can match eol */
YY_RULE_SETUP
#line 333 "libs/vkd3d-shader/hlsl.l"
{
                            FIXME("Malformed preprocessor line directive?\n");
                            BEGIN(INITIAL);
                        }
	YY_BREAK
case 169:
/* rule 169 can match eol */
YY_RULE_SETUP
#line 337 "libs/vkd3d-shader/hlsl.l"
{
                            BEGIN(INITIAL);
                        }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 340 "libs/vkd3d-shader/hlsl.l"
{}
	YY_BREAK
case 171:
/* rule 171 can match eol */
YY_RULE_SETUP
#line 341 "libs/vkd3d-shader/hlsl.l"
{
                            FIXME("Unexpected preprocessor directive.\n");
                            BEGIN(INITIAL);
                        }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 345 "libs/vkd3d-shader/hlsl.l"
{}
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 347 "libs/vkd3d-shader/hlsl.l"
{
                            return (unsigned char)yytext[0];
                        }
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 351 "libs/vkd3d-shader/hlsl.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 2666 "libs/vkd3d-shader/hlsl.yy.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(pp):
case YY_STATE_EOF(pp_line):
case YY_STATE_EOF(pp_pragma):
case YY_STATE_EOF(pp_ignore):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1065 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1065 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 1064);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 351 "libs/vkd3d-shader/hlsl.l"


static void update_location(struct hlsl_ctx *ctx, YYLTYPE *lloc)
{
    *lloc = ctx->location;
    ctx->location.column += yyget_leng(ctx->scanner);
}

int hlsl_lexer_compile(struct hlsl_ctx *ctx, const struct vkd3d_shader_code *hlsl)
{
    YY_BUFFER_STATE buffer;
    int ret;

    yylex_init_extra(ctx, &ctx->scanner);
    buffer = yy_scan_bytes(hlsl->code, hlsl->size, ctx->scanner);
    yy_switch_to_buffer(buffer, ctx->scanner);

    ret = hlsl_yyparse(ctx->scanner, ctx);

    yy_delete_buffer(buffer, ctx->scanner);
    yylex_destroy(ctx->scanner);
    return ret;
}

static void apply_escape_sequences(char *str)
{
    unsigned int i = 0, k = 0, r;

    while (str[i])
    {
        unsigned char v = 0;

        if (str[i] != '\\')
        {
            str[k++] = str[i];
            ++i;
            continue;
        }

        ++i;
        VKD3D_ASSERT(str[i]);

        if ('0' <= str[i] && str[i] <= '7')
        {
            /* octal, up to 3 digits. */
            for (r = 0; r < 3; ++r)
            {
                char c = str[i];

                if ('0' <= c && c <= '7')
                {
                    v = v << 3;
                    v += c - '0';
                    ++i;
                }
                else
                    break;
            }
            str[k++] = v;
            continue;
        }

        if (str[i] == 'x')
        {
            bool number = false;

            /* hexadecimal */
            ++i;
            while (1)
            {
                char c = str[i];

                if ('0' <= c && c <= '9')
                {
                    v = v << 4;
                    v += c - '0';
                    number = true;
                    ++i;
                }
                else if ('a' <= c && c <= 'f')
                {
                    v = v << 4;
                    v += c - 'a' + 10;
                    number = true;
                    ++i;
                }
                else if ('A' <= c && c <= 'F')
                {
                    v = v << 4;
                    v += c - 'A' + 10;
                    number = true;
                    ++i;
                }
                else
                    break;
            }
            if (number)
                str[k++] = v;
            else
                str[k++] = 'x';
            continue;
        }

        switch (str[i])
        {
            case 'a':
                str[k++] = '\a';
                break;
            case 'b':
                str[k++] = '\b';
                break;
            case 'f':
                str[k++] = '\f';
                break;
            case 'n':
                str[k++] = '\n';
                break;
            case 'r':
                str[k++] = '\r';
                break;
            case 't':
                str[k++] = '\t';
                break;
            case 'v':
                str[k++] = '\v';
                break;

            default:
                str[k++] = str[i];
                break;
        }
        ++i;
    }
    str[k++] = '\0';
}

